==> qtjambi-qt3dcore-debuginfo-macos-5.15.20.jar: sources/QtJambi3DCore/QNodeId_shell.cpp <==
#include <QtCore/QtGlobal>
#include <Qt3DCore/qnodeid.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_Qt3DCore_QNodeId(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QNodeId")
    Qt3DCore::QNodeId *_ptr = reinterpret_cast<Qt3DCore::QNodeId *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QNodeId()
void __qt_construct_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeId()")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QNodeId *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeId();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QNodeId::QNodeId()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_initialize_1native__Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeId::QNodeId()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeId, sizeof(Qt3DCore::QNodeId), typeid(Qt3DCore::QNodeId), false, &deleter_Qt3DCore_QNodeId, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QNodeId(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QNodeId_cref_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeId(Qt3DCore::QNodeId)")
    jobject other0 = __java_arguments[0].l;
    const Qt3DCore::QNodeId& __qt_other0 = qtjambi_cast<const Qt3DCore::QNodeId& >(__jni_env, other0);
    Qt3DCore::QNodeId *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeId(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QNodeId::QNodeId(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_initialize_1native__Lio_qt_qt3d_core_QNodeId_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeId::QNodeId(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeId_cref_Qt3DCore_QNodeId, sizeof(Qt3DCore::QNodeId), typeid(Qt3DCore::QNodeId), false, &deleter_Qt3DCore_QNodeId, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct Qt3DCore::QNodeId
void __qt_destruct_Qt3DCore_QNodeId(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QNodeId")
    reinterpret_cast<Qt3DCore::QNodeId*>(ptr)->~QNodeId();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QNodeId::id()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_id_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::id()const", __qt_this)
        quint64 __qt_return_value = __qt_this->id();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::operator<(Qt3DCore::QNodeId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_operator_1less_1native_1Qt3DCore_1QNodeId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::operator<(Qt3DCore::QNodeId)const", __qt_this)
        Qt3DCore::QNodeId __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<Qt3DCore::QNodeId>(other0);
        __java_return_value = (*__qt_this) < __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::operator==(Qt3DCore::QNodeId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_equals_1native_1Qt3DCore_1QNodeId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::operator==(Qt3DCore::QNodeId)const", __qt_this)
        Qt3DCore::QNodeId __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<Qt3DCore::QNodeId>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::createId()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_createId__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeId::createId()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Qt3DCore::QNodeId __qt_return_value = Qt3DCore::QNodeId::createId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = Qt3DCore::qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_Qt3DCore_QNodeId(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<Qt3DCore::QNodeId>("Qt3DCore::QNodeId", "io/qt/qt3d/core/QNodeId");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QNodeId, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QNodeId, nullptr)
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QNodeId_cref_Qt3DCore_QNodeId, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QNodeId);
    registerMetaType<Qt3DCore::QNodeId>("Qt3DCore::QNodeId");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-macos-6.5.4.jar: sources/QtJambi3DCore/QNodeId_shell.cpp <==
#include <QtCore/QtGlobal>
#include <Qt3DCore/qnodeid.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_Qt3DCore_QNodeId(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QNodeId")
    Qt3DCore::QNodeId *_ptr = reinterpret_cast<Qt3DCore::QNodeId *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QNodeId()
void __qt_construct_Qt3DCore_QNodeId_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNodeId()")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QNodeId *__qt_this = new(__qtjambi_ptr) Qt3DCore::QNodeId();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct Qt3DCore::QNodeId
void __qt_destruct_Qt3DCore_QNodeId(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QNodeId")
    reinterpret_cast<Qt3DCore::QNodeId*>(ptr)->~QNodeId();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QNodeId::QNodeId()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_initialize_1native__Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeId::QNodeId()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QNodeId_0, sizeof(Qt3DCore::QNodeId), typeid(Qt3DCore::QNodeId), false, &deleter_Qt3DCore_QNodeId, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QNodeId::id()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_id_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::id()const", __qt_this)
        quint64 __qt_return_value = __qt_this->id();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::operator<(Qt3DCore::QNodeId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_operator_1less_1native_1Qt3DCore_1QNodeId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::operator<(Qt3DCore::QNodeId)const", __qt_this)
        Qt3DCore::QNodeId __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<Qt3DCore::QNodeId>(other0);
        __java_return_value = (*__qt_this) < __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::operator==(Qt3DCore::QNodeId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_equals_1native_1Qt3DCore_1QNodeId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QNodeId::operator==(Qt3DCore::QNodeId)const", __qt_this)
        Qt3DCore::QNodeId __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<Qt3DCore::QNodeId>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QNodeId::createId()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_createId__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QNodeId::createId()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Qt3DCore::QNodeId __qt_return_value = Qt3DCore::QNodeId::createId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = Qt3DCore::qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QNodeId_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const Qt3DCore::QNodeId *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QNodeId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_Qt3DCore_QNodeId(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<Qt3DCore::QNodeId>("Qt3DCore::QNodeId", "io/qt/qt3d/core/QNodeId");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QNodeId, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QNodeId_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QNodeId);
    registerMetaType<Qt3DCore::QNodeId>("Qt3DCore::QNodeId");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
